<?php

namespace Beejees\Career\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Beejees\Career\Models\Carrier;

class CarrierPolicy
{

    /**
     * Determine if the given user can view the carrier.
     *
     * @param UserPolicyInterface $authUser
     * @param Carrier $carrier
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Carrier $carrier)
    {
        if ($authUser->canDo('career.carrier.view') && $authUser->isAdmin()) {
            return true;
        }

        return $carrier->user_id == user_id() && $carrier->user_type == user_type();
    }

    /**
     * Determine if the given user can create a carrier.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('career.carrier.create');
    }

    /**
     * Determine if the given user can update the given carrier.
     *
     * @param UserPolicyInterface $authUser
     * @param Carrier $carrier
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Carrier $carrier)
    {
        if ($authUser->canDo('career.carrier.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $carrier->user_id == user_id() && $carrier->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given carrier.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Carrier $carrier)
    {
        return $carrier->user_id == user_id() && $carrier->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given carrier.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Carrier $carrier)
    {
        if ($authUser->canDo('career.carrier.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given carrier.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Carrier $carrier)
    {
        if ($authUser->canDo('career.carrier.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
